@@ -19,6 +19,7 @@ from cryptoapis.api.automatic_coins_forwarding_api import AutomaticCoinsForwardi
 from cryptoapis.api.automatic_tokens_forwarding_api import AutomaticTokensForwardingApi
 from cryptoapis.api.create_subscriptions_for_api import CreateSubscriptionsForApi
 from cryptoapis.api.exchange_rates_api import ExchangeRatesApi
+from cryptoapis.api.features_api import FeaturesApi
 from cryptoapis.api.generating_api import GeneratingApi
 from cryptoapis.api.informative_api import InformativeApi
 from cryptoapis.api.manage_subscriptions_api import ManageSubscriptionsApi
@@ -28,7 +29,6 @@ from cryptoapis.api.tokens_api import TokensApi
 from cryptoapis.api.transactions_api import TransactionsApi
 from cryptoapis.api.utxo_based_api import UTXOBasedApi
 from cryptoapis.api.unified_endpoints_api import UnifiedEndpointsApi
-from cryptoapis.api.validating_api import ValidatingApi
 from cryptoapis.api.xrp__ripple_api import XRPRippleApi
 from cryptoapis.api.zilliqa_api import ZilliqaApi
 from cryptoapis.api.internal_api import InternalApi
