@@ -71,6 +71,18 @@ from cryptoapis.model.blockchain_data_transaction_not_found import BlockchainDat
 from cryptoapis.model.blockchain_data_transaction_not_found_error import BlockchainDataTransactionNotFoundError
 from cryptoapis.model.blockchain_events_callbacks_limit_reached import BlockchainEventsCallbacksLimitReached
 from cryptoapis.model.blockchain_events_callbacks_limit_reached_error import BlockchainEventsCallbacksLimitReachedError
+from cryptoapis.model.broadcast_locally_signed_transaction_r import BroadcastLocallySignedTransactionR
+from cryptoapis.model.broadcast_locally_signed_transaction_rb import BroadcastLocallySignedTransactionRB
+from cryptoapis.model.broadcast_locally_signed_transaction_rb_data import BroadcastLocallySignedTransactionRBData
+from cryptoapis.model.broadcast_locally_signed_transaction_rb_data_item import BroadcastLocallySignedTransactionRBDataItem
+from cryptoapis.model.broadcast_locally_signed_transaction_r_data import BroadcastLocallySignedTransactionRData
+from cryptoapis.model.broadcast_locally_signed_transaction_ri import BroadcastLocallySignedTransactionRI
+from cryptoapis.model.broadcast_transaction_fail import BroadcastTransactionFail
+from cryptoapis.model.broadcast_transaction_fail_data import BroadcastTransactionFailData
+from cryptoapis.model.broadcast_transaction_fail_data_item import BroadcastTransactionFailDataItem
+from cryptoapis.model.broadcast_transaction_success import BroadcastTransactionSuccess
+from cryptoapis.model.broadcast_transaction_success_data import BroadcastTransactionSuccessData
+from cryptoapis.model.broadcast_transaction_success_data_item import BroadcastTransactionSuccessDataItem
 from cryptoapis.model.coins_forwarding_automations_limit_reached import CoinsForwardingAutomationsLimitReached
 from cryptoapis.model.coins_forwarding_automations_limit_reached_error import CoinsForwardingAutomationsLimitReachedError
 from cryptoapis.model.coins_forwarding_fail import CoinsForwardingFail
@@ -111,7 +123,7 @@ from cryptoapis.model.create_coins_transaction_request_from_wallet_r import Crea
 from cryptoapis.model.create_coins_transaction_request_from_wallet_rb import CreateCoinsTransactionRequestFromWalletRB
 from cryptoapis.model.create_coins_transaction_request_from_wallet_rb_data import CreateCoinsTransactionRequestFromWalletRBData
 from cryptoapis.model.create_coins_transaction_request_from_wallet_rb_data_item import CreateCoinsTransactionRequestFromWalletRBDataItem
-from cryptoapis.model.create_coins_transaction_request_from_wallet_rb_data_item_destinations import CreateCoinsTransactionRequestFromWalletRBDataItemDestinations
+from cryptoapis.model.create_coins_transaction_request_from_wallet_rb_data_item_recipients import CreateCoinsTransactionRequestFromWalletRBDataItemRecipients
 from cryptoapis.model.create_coins_transaction_request_from_wallet_r_data import CreateCoinsTransactionRequestFromWalletRData
 from cryptoapis.model.create_coins_transaction_request_from_wallet_ri import CreateCoinsTransactionRequestFromWalletRI
 from cryptoapis.model.create_coins_transaction_request_from_wallet_ri_recipients import CreateCoinsTransactionRequestFromWalletRIRecipients
@@ -122,10 +134,10 @@ from cryptoapis.model.create_tokens_transaction_request_from_address_rb_data_ite
 from cryptoapis.model.create_tokens_transaction_request_from_address_r_data import CreateTokensTransactionRequestFromAddressRData
 from cryptoapis.model.create_tokens_transaction_request_from_address_ri import CreateTokensTransactionRequestFromAddressRI
 from cryptoapis.model.create_tokens_transaction_request_from_address_ri_recipients import CreateTokensTransactionRequestFromAddressRIRecipients
+from cryptoapis.model.create_tokens_transaction_request_from_address_ris import CreateTokensTransactionRequestFromAddressRIS
+from cryptoapis.model.create_tokens_transaction_request_from_address_risb import CreateTokensTransactionRequestFromAddressRISB
+from cryptoapis.model.create_tokens_transaction_request_from_address_rise import CreateTokensTransactionRequestFromAddressRISE
 from cryptoapis.model.create_tokens_transaction_request_from_address_ri_senders import CreateTokensTransactionRequestFromAddressRISenders
-from cryptoapis.model.create_tokens_transaction_request_from_address_ri_token_type_specific_data import CreateTokensTransactionRequestFromAddressRITokenTypeSpecificData
-from cryptoapis.model.create_tokens_transaction_request_from_address_ri_token_type_specific_data_bitcoin_omni_token import CreateTokensTransactionRequestFromAddressRITokenTypeSpecificDataBitcoinOmniToken
-from cryptoapis.model.create_tokens_transaction_request_from_address_ri_token_type_specific_data_ethereum_erc20_token import CreateTokensTransactionRequestFromAddressRITokenTypeSpecificDataEthereumErc20Token
 from cryptoapis.model.delete_automatic_coins_forwarding_r import DeleteAutomaticCoinsForwardingR
 from cryptoapis.model.delete_automatic_coins_forwarding_r_data import DeleteAutomaticCoinsForwardingRData
 from cryptoapis.model.delete_automatic_coins_forwarding_ri import DeleteAutomaticCoinsForwardingRI
@@ -144,12 +156,12 @@ from cryptoapis.model.endpoint_not_allowed_for_plan import EndpointNotAllowedFor
 from cryptoapis.model.endpoint_not_allowed_for_plan_error import EndpointNotAllowedForPlanError
 from cryptoapis.model.feature_mainnets_not_allowed_for_plan import FeatureMainnetsNotAllowedForPlan
 from cryptoapis.model.feature_mainnets_not_allowed_for_plan_error import FeatureMainnetsNotAllowedForPlanError
-from cryptoapis.model.generate_receiving_address_r import GenerateReceivingAddressR
-from cryptoapis.model.generate_receiving_address_rb import GenerateReceivingAddressRB
-from cryptoapis.model.generate_receiving_address_rb_data import GenerateReceivingAddressRBData
-from cryptoapis.model.generate_receiving_address_rb_data_item import GenerateReceivingAddressRBDataItem
-from cryptoapis.model.generate_receiving_address_r_data import GenerateReceivingAddressRData
-from cryptoapis.model.generate_receiving_address_ri import GenerateReceivingAddressRI
+from cryptoapis.model.generate_deposit_address_r import GenerateDepositAddressR
+from cryptoapis.model.generate_deposit_address_rb import GenerateDepositAddressRB
+from cryptoapis.model.generate_deposit_address_rb_data import GenerateDepositAddressRBData
+from cryptoapis.model.generate_deposit_address_rb_data_item import GenerateDepositAddressRBDataItem
+from cryptoapis.model.generate_deposit_address_r_data import GenerateDepositAddressRData
+from cryptoapis.model.generate_deposit_address_ri import GenerateDepositAddressRI
 from cryptoapis.model.get_address_details_r import GetAddressDetailsR
 from cryptoapis.model.get_address_details_r_data import GetAddressDetailsRData
 from cryptoapis.model.get_address_details_ri import GetAddressDetailsRI
@@ -330,14 +342,17 @@ from cryptoapis.model.list_assets_details_r_data import ListAssetsDetailsRData
 from cryptoapis.model.list_assets_details_ri import ListAssetsDetailsRI
 from cryptoapis.model.list_assets_details_ri_asset_logo import ListAssetsDetailsRIAssetLogo
 from cryptoapis.model.list_assets_details_ri_latest_rate import ListAssetsDetailsRILatestRate
-from cryptoapis.model.list_assets_details_ri_specific_data import ListAssetsDetailsRISpecificData
-from cryptoapis.model.list_assets_details_ri_specific_data_crypto_type_data import ListAssetsDetailsRISpecificDataCryptoTypeData
+from cryptoapis.model.list_assets_details_ris import ListAssetsDetailsRIS
+from cryptoapis.model.list_assets_details_risc import ListAssetsDetailsRISC
 from cryptoapis.model.list_blockchain_events_subscriptions_r import ListBlockchainEventsSubscriptionsR
 from cryptoapis.model.list_blockchain_events_subscriptions_r_data import ListBlockchainEventsSubscriptionsRData
 from cryptoapis.model.list_blockchain_events_subscriptions_ri import ListBlockchainEventsSubscriptionsRI
 from cryptoapis.model.list_coins_forwarding_automations_r import ListCoinsForwardingAutomationsR
 from cryptoapis.model.list_coins_forwarding_automations_r_data import ListCoinsForwardingAutomationsRData
 from cryptoapis.model.list_coins_forwarding_automations_ri import ListCoinsForwardingAutomationsRI
+from cryptoapis.model.list_deposit_addresses_r import ListDepositAddressesR
+from cryptoapis.model.list_deposit_addresses_r_data import ListDepositAddressesRData
+from cryptoapis.model.list_deposit_addresses_ri import ListDepositAddressesRI
 from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_r import ListHDWalletXPubYPubZPubTransactionsR
 from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_r_data import ListHDWalletXPubYPubZPubTransactionsRData
 from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_ri import ListHDWalletXPubYPubZPubTransactionsRI
@@ -366,9 +381,6 @@ from cryptoapis.model.list_omni_transactions_by_block_height_ri import ListOmniT
 from cryptoapis.model.list_omni_transactions_by_block_height_ri_fee import ListOmniTransactionsByBlockHeightRIFee
 from cryptoapis.model.list_omni_transactions_by_block_height_ri_recipients import ListOmniTransactionsByBlockHeightRIRecipients
 from cryptoapis.model.list_omni_transactions_by_block_height_ri_senders import ListOmniTransactionsByBlockHeightRISenders
-from cryptoapis.model.list_receiving_addresses_r import ListReceivingAddressesR
-from cryptoapis.model.list_receiving_addresses_r_data import ListReceivingAddressesRData
-from cryptoapis.model.list_receiving_addresses_ri import ListReceivingAddressesRI
 from cryptoapis.model.list_supported_assets_r import ListSupportedAssetsR
 from cryptoapis.model.list_supported_assets_r_data import ListSupportedAssetsRData
 from cryptoapis.model.list_supported_assets_ri import ListSupportedAssetsRI
@@ -598,17 +610,20 @@ from cryptoapis.model.transaction_mined import TransactionMined
 from cryptoapis.model.transaction_mined_data import TransactionMinedData
 from cryptoapis.model.transaction_mined_data_item import TransactionMinedDataItem
 from cryptoapis.model.transaction_mined_data_item_mined_in_block import TransactionMinedDataItemMinedInBlock
-from cryptoapis.model.transaction_request_approve import TransactionRequestApprove
-from cryptoapis.model.transaction_request_approve_data import TransactionRequestApproveData
-from cryptoapis.model.transaction_request_approve_data_item import TransactionRequestApproveDataItem
+from cryptoapis.model.transaction_request_approval import TransactionRequestApproval
+from cryptoapis.model.transaction_request_approval_data import TransactionRequestApprovalData
+from cryptoapis.model.transaction_request_approval_data_item import TransactionRequestApprovalDataItem
 from cryptoapis.model.transaction_request_broadcasted import TransactionRequestBroadcasted
 from cryptoapis.model.transaction_request_broadcasted_data import TransactionRequestBroadcastedData
 from cryptoapis.model.transaction_request_broadcasted_data_item import TransactionRequestBroadcastedDataItem
+from cryptoapis.model.transaction_request_fail import TransactionRequestFail
+from cryptoapis.model.transaction_request_fail_data import TransactionRequestFailData
+from cryptoapis.model.transaction_request_fail_data_item import TransactionRequestFailDataItem
 from cryptoapis.model.transaction_request_mined import TransactionRequestMined
 from cryptoapis.model.transaction_request_mined_data import TransactionRequestMinedData
-from cryptoapis.model.transaction_request_reject import TransactionRequestReject
-from cryptoapis.model.transaction_request_reject_data import TransactionRequestRejectData
-from cryptoapis.model.transaction_request_reject_data_item import TransactionRequestRejectDataItem
+from cryptoapis.model.transaction_request_rejection import TransactionRequestRejection
+from cryptoapis.model.transaction_request_rejection_data import TransactionRequestRejectionData
+from cryptoapis.model.transaction_request_rejection_data_item import TransactionRequestRejectionDataItem
 from cryptoapis.model.unexpected_server_error import UnexpectedServerError
 from cryptoapis.model.unexpected_server_error_error import UnexpectedServerErrorError
 from cryptoapis.model.unsupported_media_type import UnsupportedMediaType
